Learn R Programming

edeR (version 1.0.0)

extractMbox: Extracts emails from specified folder

Description

This function extracts email data from a specified folder

Usage

extractMbox(username, password, folder, nmail = -1)

Arguments

username
A character string of email address for example, "xxx@gmail.com"
password
A character string of password of the email address for example "xyz123"
folder
A character string of specific folder or label name from where the email data will be extracted
nmail
An integer for the number of emails to extract, default is all emails (nmail=-1)

Value

n_message
Number of available email in the specified folder
data
The extracted data frame with the field unique id (uid), sender (from), receiver either direct or cc'd (to), subject of mail (subj), time stamp (datetime)

Details

This function allow users to extract email data from specified folder. By default this function will extract all available emails from the specified folder but user can restrict number of emails to extract using nmail.

See Also

extractBetween

Examples

Run this code
## Not run: 
# # Extract maximum 5 emails from the specified folder
# dat<-extractMbox(username="username@gmail.com",
#                  password="password",
#                  folder="folder",
#                  nmail=5)
#  ## End(Not run)

Run the code above in your browser using DataLab